﻿Imports HidLibrary

Public Class Form1

	'操作対象のHIDデバイス
	Dim VendorID As Integer = &H483         'ベンダーID
	Dim ProductID As Integer = &H5750       'プロダクトID

	'Btn_Pause.textについて
	Dim PlayingText As String = "一時停止する"
	Dim PosingText As String = "再開する（一時停止中）"

	'現在再生中 又は最後に発呼した値
	Dim NowPattern As Byte = 0   'パターン
	Dim NowSpeed As Byte = 0     '速度

	'ボタンコントロールの配列
	Dim Btn_Patterns(9) As Button    'パターン
	Dim Btn_Speeds(10) As Button    '速度

#Region "HID制御関連"

	''' <summary>HIDデバイスを取得し、制御コマンドを送信する</summary>
	Private Sub SendCommand()
		Dim TargetHID As HidDevice = HidDevices.Enumerate(VendorID, ProductID).FirstOrDefault   'HIDデバイスを取得
		If TargetHID Is Nothing Then    'デバイスが見つからなかったときは
			'特に何もしない
			'ここではステータスバーにメッセージを表示する
			TSSL_Message.Text = "HIDデバイスが見つかりませんでした…"
		Else    'デバイスが見つかったときは
			'送信するメッセージを作成する
			Dim SendMessage(15) As Byte     'メモリを確保
			'メッセージの初期状態を作成
			SendMessage(0) = &H0        '空文字
			SendMessage(1) = &H3C       '<
			SendMessage(2) = &H30       '0
			SendMessage(3) = &H31       '1
			SendMessage(4) = &H35       '5
			SendMessage(5) = &H32       'A
			SendMessage(6) = &H30       'B(解除/一時停止)
			SendMessage(7) = &H30       'C(回転パターン0～9)
			SendMessage(8) = &H30       'D(回転速度)
			SendMessage(9) = &H30       'E
			SendMessage(10) = &H30     'F
			SendMessage(11) = &H1       'G
			SendMessage(12) = &H2       'H
			SendMessage(13) = &H3       'I
			SendMessage(14) = &H68      '68
			SendMessage(15) = &H3E      '>

			'最後の操作状態からメッセージを編集する
			Select Case Btn_Pause.Text              '一時停止操作のボタン文字列が
				Case PosingText         '「再開する」なら
					SendMessage(6) = &H31       '一時停止
				Case PlayingText        '「一時停止する」なら
					SendMessage(6) = &H30       '解除
			End Select
			SendMessage(7) = &H30 + NowPattern  '回転パターン0～9
			SendMessage(8) = &H30 + NowSpeed    '回転速度

			'通信する
			TargetHID.OpenDevice()              'デバイスを開く
			TargetHID.Write(SendMessage)    'コマンドを送信
			TargetHID.CloseDevice()              'デバイスを閉じる
			TargetHID.Dispose()                    'オブジェクトを破棄

			TSSL_Message.Text = "制御コマンド「" & System.Text.Encoding.UTF8.GetString(SendMessage) & "」を送信しました"

		End If

		'サンプルとして可読性を損なわないようにエラーフック等は省略しています
	End Sub

#End Region

#Region "画面制御関連"

	''' <summary>フォームがロードされたとき</summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	Private Sub Form1_Load(sender As Object, e As EventArgs) Handles Me.Load

		'ボタンコントロールを配列に登録する
		'パターン
		Btn_Patterns(0) = Btn_Pattern0
		Btn_Patterns(1) = Btn_Pattern1
		Btn_Patterns(2) = Btn_Pattern2
		Btn_Patterns(3) = Btn_Pattern3
		Btn_Patterns(4) = Btn_Pattern4
		Btn_Patterns(5) = Btn_Pattern5
		Btn_Patterns(6) = Btn_Pattern6
		Btn_Patterns(7) = Btn_Pattern7
		Btn_Patterns(8) = Btn_Pattern8
		Btn_Patterns(9) = Btn_Pattern9
		'スピード
		Btn_Speeds(0) = Btn_Speed00
		Btn_Speeds(1) = Btn_Speed01
		Btn_Speeds(2) = Btn_Speed02
		Btn_Speeds(3) = Btn_Speed03
		Btn_Speeds(4) = Btn_Speed04
		Btn_Speeds(5) = Btn_Speed05
		Btn_Speeds(6) = Btn_Speed06
		Btn_Speeds(7) = Btn_Speed07
		Btn_Speeds(8) = Btn_Speed08
		Btn_Speeds(9) = Btn_Speed09
		Btn_Speeds(10) = Btn_Speed10

		Draw()     '画面描画

		'最初のコマンド送信
		SendCommand()   '停止状態にする

	End Sub

	''' <summary>フォームが閉じる時</summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	Private Sub Form1_FormClosed(sender As Object, e As FormClosedEventArgs) Handles Me.FormClosed
		'念のために初期状態にする
		Btn_Pause.Text = PlayingText    '一時停止の状態は再生中に
		NowPattern = 0                        'パターン
		NowSpeed = 0                         '速度
		SendCommand()                      '停止状態にする
	End Sub

	''' <summary>メニューの「終了」が押下されたとき</summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	Private Sub 終了ToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles 終了ToolStripMenuItem.Click
		Application.Exit()      'アプリを終了
	End Sub

	''' <summary>一時停止ボタンが押下されたとき</summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	Private Sub Btn_Pause_Click(sender As Object, e As EventArgs) Handles Btn_Pause.Click
		Select Case Btn_Pause.Text
			Case PlayingText '「一時停止する」と表示されているとき
				Btn_Pause.Text = PosingText     '「再開する」に表示を切り替える
				Exit Select
			Case PosingText '「再開する」と表示されているとき
				Btn_Pause.Text = PlayingText        '「一時停止する」に表示を切り替える
				Exit Select
		End Select
		SendCommand()   'デバイスへコマンド送信
	End Sub

	''' <summary>パターン切り替えボタンが押下されたとき</summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	Private Sub Btn_Pattern_Click(sender As Object, e As EventArgs) Handles Btn_Pattern0.Click,
																Btn_Pattern1.Click,
																Btn_Pattern2.Click,
																Btn_Pattern3.Click,
																Btn_Pattern4.Click,
																Btn_Pattern5.Click,
																Btn_Pattern6.Click,
																Btn_Pattern7.Click,
																Btn_Pattern8.Click,
																Btn_Pattern9.Click
		NowPattern = CByte(CType(sender, Button).Text)                        '新しい値を登録
		Draw()                                                                                     '画面描画
		SendCommand()                                                                       'デバイスへコマンド送信
	End Sub

	''' <summary>スピード切り替えボタンが押下されたとき</summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	Private Sub Btn_Speed_Click(sender As Object, e As EventArgs) Handles Btn_Speed00.Click,
																Btn_Speed01.Click,
																Btn_Speed02.Click,
																Btn_Speed03.Click,
																Btn_Speed04.Click,
																Btn_Speed05.Click,
																Btn_Speed06.Click,
																Btn_Speed07.Click,
																Btn_Speed08.Click,
																Btn_Speed09.Click,
																Btn_Speed10.Click
		NowSpeed = CByte(CType(sender, Button).Text)                          '新しい値を登録
		Draw()                                                                                      '画面描画
		SendCommand()                                                                        'デバイスへコマンド送信
	End Sub

	''' <summary>画面を描画する</summary>
	Private Sub Draw()
		'ボタンの背景色をリセットする
		For Each Btn_Pattern As Button In Btn_Patterns
			Btn_Pattern.BackColor = SystemColors.Control    'パターン
		Next
		Btn_Patterns(NowPattern).BackColor = SystemColors.ControlDark

		For Each Btn_Speed As Button In Btn_Speeds
			Btn_Speed.BackColor = SystemColors.Control      'スピード
		Next
		Btn_Speeds(NowSpeed).BackColor = SystemColors.ControlDark

		Btn_Pause.BackColor = SystemColors.Control              '一時停止
	End Sub

#End Region

End Class
